@@ -25,6 +25,7 @@ use fluence_app_service::FaaSModuleConfig;
 use fluence_app_service::TomlAppServiceConfig;
 
 use serde::Deserialize;
+use serde_json::Value as JValue;
 
 use std::collections::HashMap;
 use std::fs;
@@ -56,7 +57,7 @@ struct CallModuleArguments<'args> {
     module_name: &'args str,
     func_name: &'args str,
     show_result_arg: bool,
-    args: serde_json::Value,
+    args: JValue,
     call_parameters: CallParameters,
 }
 
@@ -81,11 +82,12 @@ impl REPL {
             Some("e") | Some("envs") => self.show_envs(args),
             Some("f") | Some("fs") => self.show_fs(args),
             Some("i") | Some("interface") => self.show_interface(),
+            Some("s") | Some("stats") => self.show_memory_stats(),
             Some("q") | Some("quit") => {
                 return false;
             }
 
-            _ => print_help(),
+            Some("h") | Some("help") | _ => print_help(),
         }
 
         true
@@ -206,6 +208,12 @@ impl REPL {
         print!("Loaded modules interface:\n{}", interface);
     }
 
+    fn show_memory_stats(&mut self) {
+        let statistic = self.app_service.module_memory_stats();
+
+        print!("Loaded modules heap sizes:\n{}", statistic);
+    }
+
     fn create_app_service<S: Into<PathBuf>>(config_file_path: Option<S>) -> ReplResult<AppService> {
         let tmp_path: String = std::env::temp_dir().to_string_lossy().into();
         let service_id = uuid::Uuid::new_v4().to_string();
@@ -251,7 +259,7 @@ fn parse_call_module_arguments<'args>(
     let module_arg: String = args.join(" ");
     let mut de = serde_json::Deserializer::from_str(&module_arg);
 
-    let args = match serde_json::Value::deserialize(&mut de) {
+    let args = match JValue::deserialize(&mut de) {
         Ok(args) => args,
         Err(e) => return Err(format!("invalid args: {}", e)),
     };
@@ -287,6 +295,7 @@ fn print_help() {
             u/unload <module_name>                                unload a Wasm module\n\
             c/call <module_name> <func_name> <args> [call_params] call function with given name from given module\n\
             i/interface                                           print public interface of all loaded modules\n\
+            s/stats                                               print memory size of all loaded modules\n\
             e/envs <module_name>                                  print environment variables of a module\n\
             f/fs <module_name>                                    print filesystem state of a module\n\
             h/help                                                print this message\n\
